@@ -15,7 +15,7 @@
 import argparse
 
 def add_subparser(subparsers):
-    _parser = subparsers.add_parser("houston", description="QuantRocket Houston API Gateway CLI", help="quantrocket houston -h")
+    _parser = subparsers.add_parser("houston", description="QuantRocket Houston API Gateway CLI", help="Connect to houston API gateway")
     _subparsers = _parser.add_subparsers(title="subcommands", dest="subcommand")
     _subparsers.required = True
 
